__author__ = 'Owais Lone'
__version__ = '0.3.3'

default_app_config = 'webpack_loader.apps.WebpackLoaderConfig'
